# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   Study_Python
# FileName:      readexcel_004.py
# Author:       xxxxxxx
# Datetime:     2023/8/7 19:20
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl
import os

from Request_framework.study_004.common.readini_004 import Read_ini_004
from Request_framework.study_004.common.readjson_004 import read_json
from Request_framework.study_004.config.settings import *


class Read_excel_004:
    def __init__(self):
        self.readini_004 = Read_ini_004()

        case_path = self.readini_004.get_file_name(CASE)
        expect_path = self.readini_004.get_file_name(EXPECT)
        sql_path = self.readini_004.get_file_name(SQL)

        self.case_data_dict = read_json(case_path)
        self.expect_data_dict = read_json(expect_path)
        self.sql_data_dict = read_json(sql_path)

        excel_path = self.readini_004.get_file_name(EXCEL)
        wb = openpyxl.load_workbook(excel_path)
        self.ws = wb[self.readini_004.get_table_name(TABLE)]

    def get_value(self, column: str, row: int) -> str:
        value = self.ws[str(column)+str(row)].value

        if value is None:
            return None
        elif value.strip():
            return value.strip()

    def module_name(self, row):
        return self.get_value(MODULE, row)

    def interface_name(self, row):
        return self.get_value(API, row)

    def case_title(self, row):
        return self.get_value(TITLE, row)

    def case_level(self, row):
        return self.get_value(LEVEL, row)

    def case_method(self, row):
        return self.get_value(METHOD, row)

    def case_url(self, row):
        host = self.readini_004.get_host(HOST)

        return host+self.get_value(PATH, row)

    def case_mime(self, row):
        value = self.get_value(MIME, row)

        if value:
            return value.lower()

    def case_data(self, row):
        case_data_key = self.get_value(CASEDATA, row)
        if case_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.case_data_dict[module_name][interface_name][case_data_key]

    def expect_data(self, row):
        expect_data_key = self.get_value(EXPECTDATA, row)
        if expect_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.expect_data_dict[module_name][interface_name][expect_data_key]

    def sql_type(self, row):
        value = self.get_value(SQLTYPE, row)
        if value:
            return value.lower()

    def sql_sentence(self, row):
        sql_data_key = self.get_value(SQLSENTENCE, row)
        if sql_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.sql_data_dict[module_name][interface_name][sql_data_key]

    def update_key(self, row):
        return self.get_value(UPDATEKEY, row)

    def into_list(self):
        list_data = []
        for row in range(2, self.ws.max_row+1):
            module = self.module_name(row)
            interface = self.interface_name(row)
            title = self.case_title(row)
            level = self.case_level(row)
            method = self.case_method(row)
            url = self.case_url(row)
            mime = self.case_mime(row)
            data = self.case_data(row)
            expect = self.expect_data(row)
            sql_type = self.sql_type(row)
            sql_sentence = self.sql_sentence(row)
            update_key = self.update_key(row)
            list_data.append([module, interface, title, level, method, url, mime, data, expect, sql_type, sql_sentence, update_key])
        else:
            return list_data


if __name__ == '__main__':
    read_excel_004 = Read_excel_004()
    print(read_excel_004.into_list())